<?php

namespace App\Nova;

use Laravel\Nova\Fields\Avatar;
use Laravel\Nova\Fields\Boolean;
use Laravel\Nova\Fields\HasMany;
use Laravel\Nova\Fields\ID;
use Illuminate\Http\Request;
use Laravel\Nova\Fields\Place;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Fields\Text;
use Laravel\Nova\Fields\Gravatar;
use Laravel\Nova\Fields\Password;

class User extends Resource
{
    /**
     * The model the resource corresponds to.
     *
     * @var string
     */
    public static $model = 'App\\Models\\User';

    /**
     * The single value that should be used to represent the resource when being displayed.
     *
     * @var string
     */
    public static $title = 'name';

    /**
     * The columns that should be searched.
     *
     * @var array
     */
    public static $search = [
        'id', 'name', 'email',
    ];

    public static function label(){
        return 'Utilisateurs';
    }

    /**
     * Get the fields displayed by the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function fields(Request $request)
    {
        return [
            ID::make()
                ->hideFromIndex()
                ->sortable(),

            Avatar::make('Photo'),

            Boolean::make('Actif', 'active')
                ->sortable()
                ->rules('required', 'max:255'),

            Select::make('Role')
                ->options([
                    'Admin' => 'Admin',
                    'Promoteur' => 'Promoteur'
                ])
                ->sortable()
                ->rules('required', 'max:255'),


            Text::make('Nom', 'name')
                ->sortable()
                ->rules('required', 'max:255'),

            Text::make('Email')
                ->sortable()
                ->rules('required', 'email', 'max:254')
                ->creationRules('unique:users,email')
                ->updateRules('unique:users,email,{{resourceId}}'),

            Password::make('Password')
                ->onlyOnForms()
                ->creationRules('required', 'string', 'min:6')
                ->updateRules('nullable', 'string', 'min:6'),

            Place::make('Adresse', 'address')
                ->sortable()
                ->rules('required', 'max:255'),

            Text::make('Ville', 'city')
                ->sortable()
                ->rules('required', 'max:255'),

            Text::make('Pays', 'country')
                ->sortable()
                ->rules('required', 'max:255'),

            Text::make("Profession", 'job')
                ->sortable()
                ->rules('required', 'max:255'),

            Text::make('Facebook')
                ->hideFromIndex()
                ->sortable()
                ,

            Text::make('twitter')
                ->hideFromIndex()
                ->sortable()
                ,

            Text::make('instagram')
                ->hideFromIndex()
                ->sortable()
               ,

            Text::make('snapchat')
                ->hideFromIndex()
                ->sortable()
                ,

            Text::make('linkedin')
                ->hideFromIndex()
                ->sortable()
                ,

            HasMany::make('events')

        ];
    }

    /**
     * Get the cards available for the request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function cards(Request $request)
    {
        return [];
    }

    /**
     * Get the filters available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function filters(Request $request)
    {
        return [];
    }

    /**
     * Get the lenses available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function lenses(Request $request)
    {
        return [];
    }

    /**
     * Get the actions available for the resource.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return array
     */
    public function actions(Request $request)
    {
        return [];
    }
}
